pub struct GpuSceneCanvas<'a, 'b> { /* private fields */ }Expand description
Adapter que pinta primitivos de Canvas sobre un GpuBatch. El
batch lo construye y flushea la app dentro del gpu_paint_with;
GpuSceneCanvas vive sólo durante las calls del painter.
Implementations